@@ -2,6 +2,7 @@ import time
 from bs4 import BeautifulSoup
 from selenium import webdriver
 import re
+from os import path
 
 
 def get_decisions(path, year, init_no=0, last_no=999999, keyword='içtihat'):
@@ -91,6 +92,15 @@ def get_decisions(path, year, init_no=0, last_no=999999, keyword='içtihat'):
         # determine file name as decision number
         file_name = text.split(" K.")[0].split(" ")[-1].replace("/", "")
 
+        if path.exists(file_name):
+            buff = 1
+            while True:
+                file_name = "{0}_{2}{1}".format(*path.splitext(file_name) + (buff,))
+                if path.exists(file_name):
+                    buff += 1
+                else:
+                    break
+
         # create file and write text
         file = open(file_name + ".txt", "w")
         file.write(text)
